@@ -23,6 +23,9 @@ describe 'cloudkitty::keystone::auth' do
         :password            => 'cloudkitty_password',
         :email               => 'cloudkitty@localhost',
         :tenant              => 'services',
+        :roles               => ['admin'],
+        :system_scope        => 'all',
+        :system_roles        => [],
         :public_url          => 'http://127.0.0.1:8889',
         :internal_url        => 'http://127.0.0.1:8889',
         :admin_url           => 'http://127.0.0.1:8889',
@@ -37,6 +40,9 @@ describe 'cloudkitty::keystone::auth' do
           :auth_name           => 'alt_cloudkitty',
           :email               => 'alt_cloudkitty@alt_localhost',
           :tenant              => 'alt_service',
+          :roles               => ['admin', 'service'],
+          :system_scope        => 'alt_all',
+          :system_roles        => ['admin', 'member', 'reader'],
           :configure_endpoint  => false,
           :configure_user      => false,
           :configure_user_role => false,
@@ -62,6 +68,9 @@ describe 'cloudkitty::keystone::auth' do
         :password            => 'cloudkitty_password',
         :email               => 'alt_cloudkitty@alt_localhost',
         :tenant              => 'alt_service',
+        :roles               => ['admin', 'service'],
+        :system_scope        => 'alt_all',
+        :system_roles        => ['admin', 'member', 'reader'],
         :public_url          => 'https://10.10.10.10:80',
         :internal_url        => 'http://10.10.10.11:81',
         :admin_url           => 'http://10.10.10.12:81',
